==> lifetype-1.1.tbz: www/lifetype/class/dao/daocacheconstants.properties.php <==
<?php
	/**
	 * article categories
	 */
    define( "CACHE_GLOBAL", "pLog" );
    define( "CACHE_CONFIGDBSTORAGE", "config_db_storage" );

	/**
	 * article categories
	 */
	define( "CACHE_ARTICLE_CATEGORIES", "article_categories" );
	define( "CACHE_ARTICLE_CATEGORIES_BYNAME", "article_categories_byname" );
	define( "CACHE_ARTICLE_CATEGORIES_BLOG", "article_categories_blog" );
	define( "CACHE_ARTICLE_CATEGORIES_LINK", "article_categories_link" );
	
	/**
	 * articles
	 */
    define( "CACHE_ARTICLES",            "articles" );
    define( "CACHE_ARTICLES_BYNAME",     "articles_byname" );    
    define( "CACHE_ARTICLETEXT",         "article_text" );    
    define( "CACHE_ARTICLESPERMONTH",    "articles_per_month" );	
	
	/**
	 * blog categories
	 */
	define( "CACHE_BLOGCATEGORIES", "cache_blog_categories" );
	define( "CACHE_BLOGCATEGORIES_ALL", "cache_blog_categories_all" );		

	/**
	 * blogs
	 */
    define( "CACHE_BLOGINFOS",     "bloginfo" );
    define( "CACHE_BLOGIDBYNAME",  "bloginfo_idbyname" );    
    define( "CACHE_BLOGIDBYDOMAIN","bloginfo_idbydomain" ); 
    
	/**
	 * article comments
	 */
	define( "CACHE_ARTICLE_COMMENTS", "article_comments" );
	define( "CACHE_ARTICLE_COMMENTS_BYARTICLE", "article_comments_byarticle" );
	 
	/**
	 * custom fields
	 */
	define( "CACHE_CUSTOMFIELDS", "customfields" );
	define( "CACHE_CUSTOMFIELDS_BLOG", "customfields_blog" );
	define( "CACHE_CUSTOMFIELDS_BY_NAME", "customfields_name" );	

	/**
	 * custom field values
	 */
    define( "CACHE_CUSTOMFIELDVALUES_ARTICLE", "customfieldvalues_article" );
	
	/**
	 * article global categories
	 */
	define( "CACHE_GLOBALCATEGORIES", "cache_global_categories" );
	define( "CACHE_GLOBALCATEGORIES_ALL", "cache_global_categories_all" );	
	
	/**
	 * links
	 */
	define( "CACHE_MYLINKS_ALL", "cache_mylinks_all" );
	define( "CACHE_MYLINKS", "cache_mylinks" );

	/**
	 * recent articles
	 */
	define( "CACHE_RECENT_ARTICLES_BY_BLOG", "recent_articles_by_blog" );
	
	/**
	 * link categories
	 */
	define( "CACHE_MYLINKCATEGORIES_ALL", "mylinks_categories_all" );
	define( "CACHE_MYLINKCATEGORIES", "mylinks_categories" );

	/**
	 * gallery albums
	 */
    define( "CACHE_USERALBUMS_NESTED", "useralbums_nested" );
	define( "CACHE_USERALBUMS", "useralbums" );
	define( "CACHE_GALLERYALBUM", "album" );
	define( "CACHE_GALLERYALBUMBYNAME", "album_byname" );

	/**
	 * gallery resources
	 */	
	define( "CACHE_RESOURCES", "galleryresources" );
	define( "CACHE_RESOURCES_BY_NAME", "galleryresources_name" );	
	define( "CACHE_RESOURCES_USER", "galleryresources_user" );	

	/**
	 * users
	 */
    define( "CACHE_USERINFO", "userinfo" );
    define( "CACHE_USERIDBYNAME", "userinfo_idbyname" );
	 
	/**
	 * user permissions
	 */
	define( "CACHE_USER_PERMISSIONS", "user_permissions" );
	
	/**
	 * locales
	 */	
    define( "CACHE_LOCALES", "locales" );
?>

==> lifetype-1.2.11.tbz: www/lifetype/class/dao/daocacheconstants.properties.php <==
<?php
	/**
	 * article categories
	 */
    define( "CACHE_GLOBAL", "pLog" );
    define( "CACHE_CONFIGDBSTORAGE", "config_db_storage" );

	/**
	 * article categories
	 */
	define( "CACHE_ARTICLE_CATEGORIES", "article_categories" );
	define( "CACHE_ARTICLE_CATEGORIES_BYNAME", "article_categories_byname" );
	define( "CACHE_ARTICLE_CATEGORIES_BLOG", "article_categories_blog" );
	define( "CACHE_ARTICLE_CATEGORIES_LINK", "article_categories_link" );
	
	/**
	 * articles
	 */
    define( "CACHE_ARTICLES",            "articles" );
    define( "CACHE_ARTICLES_BYNAME",     "articles_byname" );    
    define( "CACHE_ARTICLETEXT",         "article_text" );    
    define( "CACHE_ARTICLESPERMONTH",    "articles_per_month" );	
	
	/**
	 * blog categories
	 */
	define( "CACHE_BLOGCATEGORIES", "cache_blog_categories" );
	define( "CACHE_BLOGCATEGORIES_ALL", "cache_blog_categories_all" );		

	/**
	 * blogs
	 */
    define( "CACHE_BLOGINFOS",     "bloginfo" );
    define( "CACHE_BLOGIDBYNAME",  "bloginfo_idbyname" );    
    define( "CACHE_BLOGIDBYDOMAIN","bloginfo_idbydomain" ); 
    
	/**
	 * article comments
	 */
	define( "CACHE_ARTICLE_COMMENTS", "article_comments" );
	define( "CACHE_ARTICLE_COMMENTS_BYARTICLE_NEWEST_TO_OLDEST", "article_comments_byarticle_newest_to_oldest" );
	define( "CACHE_ARTICLE_COMMENTS_BYARTICLE_OLDEST_TO_NEWEST", "article_comments_byarticle_oldest_to_newest" );
	 
	/**
	 * custom fields
	 */
	define( "CACHE_CUSTOMFIELDS", "customfields" );
	define( "CACHE_CUSTOMFIELDS_BLOG", "customfields_blog" );
	define( "CACHE_CUSTOMFIELDS_BY_NAME", "customfields_name" );	

	/**
	 * custom field values
	 */
    define( "CACHE_CUSTOMFIELDVALUES_ARTICLE", "customfieldvalues_article" );
	
	/**
	 * article global categories
	 */
	define( "CACHE_GLOBALCATEGORIES", "cache_global_categories" );
	define( "CACHE_GLOBALCATEGORIES_ALL", "cache_global_categories_all" );	
	
	/**
	 * links
	 */
	define( "CACHE_MYLINKS_ALL", "cache_mylinks_all" );
	define( "CACHE_MYLINKS", "cache_mylinks" );

	/**
	 * recent articles
	 */
	define( "CACHE_RECENT_ARTICLES_BY_BLOG", "recent_articles_by_blog" );
	
	/**
	 * link categories
	 */
	define( "CACHE_MYLINKCATEGORIES_ALL", "mylinks_categories_all" );
	define( "CACHE_MYLINKCATEGORIES", "mylinks_categories" );

	/**
	 * gallery albums
	 */
    define( "CACHE_USERALBUMS_NESTED", "useralbums_nested" );
	define( "CACHE_USERALBUMS", "useralbums" );
	define( "CACHE_GALLERYALBUM", "album" );
	define( "CACHE_GALLERYALBUMBYNAME", "album_byname" );

	/**
	 * gallery resources
	 */	
	define( "CACHE_RESOURCES", "galleryresources" );
	define( "CACHE_RESOURCES_BY_NAME", "galleryresources_name" );	
	define( "CACHE_RESOURCES_USER", "galleryresources_user" );	

	/**
	 * users
	 */
    define( "CACHE_USERINFO", "userinfo" );
    define( "CACHE_USERIDBYNAME", "userinfo_idbyname" );
	 
	/**
	 * user permissions
	 */
	define( "CACHE_USER_PERMISSIONS", "user_permissions" );
	
	/**
	 * locales
	 */	
    define( "CACHE_LOCALES", "locales" );
    define( "CACHE_BLOG_LOCALES", "bloglocales" );
    
    /**
     * permissions
     */
    define( "CACHE_PERMISSIONS_ALL", "permissions_all" );
    define( "CACHE_PERMISSIONS", "permissions" );
?>
